==> jc-1.4.0.tar.gz: javax/swing/JMenuItem__24AccessibleJMenuItem.h <==
// public class javax.swing.JMenuItem$AccessibleJMenuItem

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 3f25717f6c53c837 javax_swing_AbstractButton__24AccessibleAbstractButton
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class 5dbfdfd99aace194 javax_swing_JMenuItem__24AccessibleJMenuItem

// header file dependencies
// @dep_header javax_swing_AbstractButton__24AccessibleAbstractButton

#include "javax/swing/AbstractButton__24AccessibleAbstractButton.h"

#ifndef _JC_javax_swing_JMenuItem__24AccessibleJMenuItem_H_
#define _JC_javax_swing_JMenuItem__24AccessibleJMenuItem_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_swing_JMenuItem$object;
struct _jc_javax_swing_event_ChangeEvent$object;

// Typedefs
typedef struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_refs	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_refs;
typedef struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_nonrefs	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_nonrefs;
typedef struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$refs	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$refs;
typedef struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$nonrefs	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$nonrefs;
typedef struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$object	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$object;

typedef struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$fields_struct	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$fields_struct;
typedef const struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vmethods	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vmethods;
typedef const struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vtable	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vtable;
typedef const struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vtype	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vtype;

// Class fields structure
struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$fields_struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$class_fields;

// Constructors
extern void _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$method$_init$339159e6e27034a1(_jc_env *, struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$object *, struct _jc_javax_swing_JMenuItem$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$object *);
extern void _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$method$stateChanged$4d8b57b35708ef83(_jc_env *, struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$object *, struct _jc_javax_swing_event_ChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$method_info$stateChanged$4d8b57b35708ef83;

// Virtual methods structure
struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$object *);
	void	(*stateChanged$4d8b57b35708ef83)(_jc_env *, struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$object *, struct _jc_javax_swing_event_ChangeEvent$object *);
};

// Vtable
struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_AbstractButton__24AccessibleAbstractButton$vmethods	javax_swing_AbstractButton__24AccessibleAbstractButton;
	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vmethods	javax_swing_JMenuItem__24AccessibleJMenuItem;
};

// Vtype
struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vtype {
	_jc_type			type;
	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_refs {
	struct _jc_javax_swing_JMenuItem$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$refs {
    _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_refs	javax_swing_JMenuItem__24AccessibleJMenuItem;
    _jc_javax_swing_AbstractButton__24AccessibleAbstractButton$sub_refs	javax_swing_AbstractButton__24AccessibleAbstractButton;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_AbstractButton__24AccessibleAbstractButton$sub_nonrefs	javax_swing_AbstractButton__24AccessibleAbstractButton;
    _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_nonrefs	javax_swing_JMenuItem__24AccessibleJMenuItem;
};

// Object instance structure
struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$object {
	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vtype	*vtype;
	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vtype _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JMenuItem__24AccessibleJMenuItem, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$class_object;

#endif	/* _JC_javax_swing_JMenuItem__24AccessibleJMenuItem_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JMenuItem__24AccessibleJMenuItem.h <==
// public class javax.swing.JMenuItem$AccessibleJMenuItem

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 3f25717f6c53c837 javax_swing_AbstractButton__24AccessibleAbstractButton
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class 5dbfdfd99aace194 javax_swing_JMenuItem__24AccessibleJMenuItem

// header file dependencies
// @dep_header javax_swing_AbstractButton__24AccessibleAbstractButton

#include "javax/swing/AbstractButton__24AccessibleAbstractButton.h"

#ifndef _JC_javax_swing_JMenuItem__24AccessibleJMenuItem_H_
#define _JC_javax_swing_JMenuItem__24AccessibleJMenuItem_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_swing_JMenuItem$object;
struct _jc_javax_swing_event_ChangeEvent$object;

// Typedefs
typedef struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_refs	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_refs;
typedef struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_nonrefs	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_nonrefs;
typedef struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$refs	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$refs;
typedef struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$nonrefs	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$nonrefs;
typedef struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$object	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$object;

typedef struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$fields_struct	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$fields_struct;
typedef const struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vmethods	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vmethods;
typedef const struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vtable	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vtable;
typedef const struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vtype	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vtype;

// Class fields structure
struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$fields_struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$class_fields;

// Constructors
extern void _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$method$_init$339159e6e27034a1(_jc_env *, struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$object *, struct _jc_javax_swing_JMenuItem$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$method$stateChanged$4d8b57b35708ef83(_jc_env *, struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$object *, struct _jc_javax_swing_event_ChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$method_info$stateChanged$4d8b57b35708ef83;

// Virtual methods structure
struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$object *) _JC_JCNI_ATTR;
	void	(*stateChanged$4d8b57b35708ef83)(_jc_env *, struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$object *, struct _jc_javax_swing_event_ChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_AbstractButton__24AccessibleAbstractButton$vmethods	javax_swing_AbstractButton__24AccessibleAbstractButton;
	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vmethods	javax_swing_JMenuItem__24AccessibleJMenuItem;
};

// Vtype
struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vtype {
	_jc_type			type;
	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_refs {
	struct _jc_javax_swing_JMenuItem$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$refs {
    _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_refs	javax_swing_JMenuItem__24AccessibleJMenuItem;
    _jc_javax_swing_AbstractButton__24AccessibleAbstractButton$sub_refs	javax_swing_AbstractButton__24AccessibleAbstractButton;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_AbstractButton__24AccessibleAbstractButton$sub_nonrefs	javax_swing_AbstractButton__24AccessibleAbstractButton;
    _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$sub_nonrefs	javax_swing_JMenuItem__24AccessibleJMenuItem;
};

// Object instance structure
struct _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$object {
	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vtype	*vtype;
	_jc_javax_swing_JMenuItem__24AccessibleJMenuItem$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$vtype _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JMenuItem__24AccessibleJMenuItem, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JMenuItem__24AccessibleJMenuItem$class_object;

#endif	/* _JC_javax_swing_JMenuItem__24AccessibleJMenuItem_H_ */
